@@ -7,6 +7,8 @@ import pprint
 import tabulate
 import datetime
 from collections import namedtuple
+from soco.events import event_listener
+from queue import Empty
 
 from . import sonos
 from . import speaker_info
@@ -582,7 +584,7 @@ def remove_from_queue(speaker, action, args, soco_function, use_local_speaker_li
     if 1 <= index <= qs:
         speaker.remove_from_queue(index - 1)
     else:
-        error_and_exit("Queue index should be between 1 and {}".format(qs))
+        error_and_exit("Queue index must be between 1 and {}".format(qs))
         return False
     return True
 
@@ -851,6 +853,32 @@ def list_all_playlist_tracks(
     return True
 
 
+@zero_parameters
+def wait_stop(speaker, action, args, soco_function, use_local_speaker_list):
+    sub = speaker.avTransport.subscribe(auto_renew=True)
+    while True:
+        try:
+            event = sub.events.get(timeout=1.0)
+            if event.variables["transport_state"] != "PLAYING":
+                sub.unsubscribe()
+                return True
+        except Empty:
+            pass
+
+
+@zero_parameters
+def wait_start(speaker, action, args, soco_function, use_local_speaker_list):
+    sub = speaker.avTransport.subscribe(auto_renew=True)
+    while True:
+        try:
+            event = sub.events.get(timeout=1.0)
+            if event.variables["transport_state"] == "PLAYING":
+                sub.unsubscribe()
+                return True
+        except Empty:
+            pass
+
+
 def process_action(speaker, action, args, use_local_speaker_list):
     sonos_function = actions.get(action, None)
     if sonos_function:
@@ -948,6 +976,7 @@ actions = {
     "pfq": SonosFunction(play_from_queue, "play_from_queue"),
     "pq": SonosFunction(play_from_queue, "play_from_queue"),
     "remove_from_queue": SonosFunction(remove_from_queue, "remove_from_queue"),
+    "rfq": SonosFunction(remove_from_queue, "remove_from_queue"),
     "rq": SonosFunction(remove_from_queue, "remove_from_queue"),
     "clear_queue": SonosFunction(no_args_no_output, "clear_queue"),
     "cq": SonosFunction(no_args_no_output, "clear_queue"),
@@ -1005,4 +1034,6 @@ actions = {
     "lpt": SonosFunction(list_playlist_tracks, "list_tracks"),
     "list_all_playlist_tracks": SonosFunction(list_all_playlist_tracks, ""),
     "lapt": SonosFunction(list_all_playlist_tracks, ""),
+    "wait_stop": SonosFunction(wait_stop, ""),
+    "wait_start": SonosFunction(wait_start, ""),
 }
